                                                                /*    GENSDAT2.SQL   */
/*       
**
**  This script loads some of the sample data for the Credit database.
**
**  All data that is randomly generated, such as members and charges, is generated in
**  GENSDAT1.DAT.  For performance reasons, GENSDAT1.DAT is run before the indexes
**  are built.  All data that is generated by running standard stored procedures,
**  such as statements and payments, is generated in GENSDAT2.SQL, which is run after
**  the indexes have been build.
**  
**  You must have submitted the GENSTBLS.SQL and GENSPROC.SQL scripts first.
**  
*/



--  Don't forget to say 'USE Credit' first.

USE Credit
SET NOCOUNT ON
GO
IF ( (SELECT db_name()) <> 'Credit')
BEGIN
   RAISERROR ('Database "Credit" not found.',22,127) WITH LOG
END
GO


PRINT 'Begin GENSDAT2.SQL'
GO

SELECT 'began' = getdate() INTO #starttime
GO



--  Load statements

DECLARE @Date1 datetime

SELECT @Date1 = DATEADD(month,-2,getdate())
EXEC load_statements @Date1

SELECT @Date1 = DATEADD(month,-1,getdate())
EXEC load_statements @Date1

SELECT @Date1 = getdate()
EXEC load_statements @Date1

DELETE statement
  WHERE statement_no > 20000
BACKUP LOG Credit WITH NO_LOG
GO



--  Load payments

DECLARE @Date1 datetime
DECLARE @Date2 datetime

SELECT @Date1 = DATEADD(month,-999,getdate())
SELECT @Date2 = DATEADD(month,-2,getdate())
EXEC load_payments @Date1, @Date2

SELECT @Date1 = DATEADD(month,-2,getdate())
SELECT @Date2 = DATEADD(month,-1,getdate())
EXEC load_payments @Date1, @Date2

SELECT @Date1 = DATEADD(month,-1,getdate())
SELECT @Date2 = getdate()
EXEC load_payments @Date1, @Date2

DELETE payment
  WHERE payment_no > 20000
BACKUP LOG Credit WITH NO_LOG
GO



--  Get and display the elapsed time.

DECLARE 
  @message char(255), 
  @began datetime  
SELECT @began = began from #starttime
SELECT ' ' = ' '
SELECT @message = 
  'Time (in minutes:seconds) to LOAD DATA ' + 
  convert( char(2), datediff(ss,@began,getdate())/60 ) + 
  ':' + 
   convert( char(2), datediff(ss,@began,getdate())%60 )    
RAISERROR(@message, 10, 1)
SELECT ' ' = ' '
GO
