/*
**  Show the size of each of the tables.
*/

--  Don't forget to say 'USE Credit' first.

USE Credit
SET NOCOUNT ON
GO
IF ( (SELECT db_name()) <> 'Credit')
BEGIN
   RAISERROR ('Database "Credit" not found.',22,127) WITH LOG
END
GO


SELECT ' '
SELECT 'TABLE     ' = convert(char(16),o.name)
     , '      ROWS' = str(i.rows)
     , '  RESERVED' = str(i.reserved)
--     , '      USED' = str(i.used)
     , '      DATA' = str(i.dpages)
     , '     INDEX' = str(i.used - i.dpages)
     , '    ROWS / PAGE' = str(i.rows / i.dpages)
FROM sysobjects o, sysindexes i
WHERE o.type = 'U'
AND i.id = o.id
AND i.indid IN (0,1)

SELECT ' '
SELECT 'TOTAL MG. ' = (convert(decimal(6,2),SUM(i.reserved))) * 2 / 1000
FROM sysobjects o, sysindexes i
WHERE o.type = 'U'
AND i.id = o.id
AND i.indid IN (0,1)
GO



--  Show the distribution of the provider data.

SELECT '  ' = '  '
SELECT '  ' = 'DISTRIBUTION OF providers PER region:'
EXEC show_dist 'provider', 'region_no'
GO


--  Show the distribution of the member data.

SELECT '  ' = '  '
SELECT '  ' = 'DISTRIBUTION OF members PER region:'
EXEC show_dist 'member', 'region_no'

SELECT '  ' = '  '
SELECT '  ' = 'DISTRIBUTION OF members PER corp:'
EXEC show_dist 'member', 'corp_no'
GO


--  Show the distribution of the statement data.

SELECT '  ' = '  '
SELECT '  ' = 'DISTRIBUTION OF statements PER member:'
EXEC show_dist 'statement', 'member_no'
GO



--  Show the distribution of the payment data.

SELECT '  ' = '  '
SELECT '  ' = 'DISTRIBUTION OF payments PER member:'
EXEC show_dist 'payment', 'member_no'
GO



--  Show the distribution of the charge data.

SELECT '  ' = '  '
SELECT '  ' = 'DISTRIBUTION OF charges PER category:'
EXEC show_dist 'charge', 'category_no'

SELECT '  ' = '  '
SELECT '  ' = 'DISTRIBUTION OF charges PER provider:'
EXEC show_dist 'charge', 'provider_no'

SELECT '  ' = '  '
SELECT '  ' = 'DISTRIBUTION OF charges PER member:'
EXEC show_dist 'charge', 'member_no'

SELECT '  ' = '  '
SELECT '  ' = 'DISTRIBUTION OF charges PER statement:'
EXEC show_dist 'charge', 'statement_no'
GO



SET NOCOUNT OFF
GO
